@@ -18,13 +18,13 @@
 from cubicweb.xy import xy
 
 
-xy.register_prefix('prov', 'http://www.w3.org/ns/prov#')
+xy.register_prefix("prov", "http://www.w3.org/ns/prov#")
 
-xy.add_equivalence('Activity', 'prov:Activity')
-xy.add_equivalence('Activity type', 'prov:type')
-xy.add_equivalence('Activity description', 'prov:label')
-xy.add_equivalence('Activity start', 'prov:startedAtTime')
-xy.add_equivalence('Activity end', 'prov:endedAtTime')
-xy.add_equivalence('Activity associated_with', 'prov:wasAssociatedWith')
-xy.add_equivalence('Activity generated', 'prov:generated')
-xy.add_equivalence('Activity used', 'prov:used')
+xy.add_equivalence("Activity", "prov:Activity")
+xy.add_equivalence("Activity type", "prov:type")
+xy.add_equivalence("Activity description", "prov:label")
+xy.add_equivalence("Activity start", "prov:startedAtTime")
+xy.add_equivalence("Activity end", "prov:endedAtTime")
+xy.add_equivalence("Activity associated_with", "prov:wasAssociatedWith")
+xy.add_equivalence("Activity generated", "prov:generated")
+xy.add_equivalence("Activity used", "prov:used")
